@@ -41,7 +41,7 @@ public:
 //@endcond
 
 //@cond PRIVATE
-class Q_DECL_HIDDEN Summary::Private
+class Q_DECL_HIDDEN Summary::SummaryPrivate
 {
 public:
     QPoint mDragStartPoint;
@@ -50,16 +50,13 @@ public:
 
 Summary::Summary(QWidget *parent)
     : QWidget(parent)
-    , d(new Private)
+    , d(new SummaryPrivate)
 {
     setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
     setAcceptDrops(true);
 }
 
-Summary::~Summary()
-{
-    delete d;
-}
+Summary::~Summary() = default;
 
 int Summary::summaryHeight() const
 {
@@ -70,7 +67,7 @@ QWidget *Summary::createHeader(QWidget *parent, const QString &iconname, const Q
 {
     auto box = new QWidget(parent);
     auto hbox = new QHBoxLayout(box);
-    hbox->setContentsMargins(0, 0, 0, 0);
+    hbox->setContentsMargins({});
     hbox->setSpacing(0);
     box->setAutoFillBackground(true);
 
@@ -94,7 +91,7 @@ QWidget *Summary::createHeader(QWidget *parent, const QString &iconname, const Q
 
 QStringList Summary::configModules() const
 {
-    return QStringList();
+    return {};
 }
 
 void Summary::configChanged()
